pub fn correct(repo: &Path, a: CorrectArgs) -> ExitCodeExpand description
Append a corrective child that fixes a stale non-hashed tag, then report the new child id.
pub fn correct(repo: &Path, a: CorrectArgs) -> ExitCodeAppend a corrective child that fixes a stale non-hashed tag, then report the new child id.